﻿using Android.App;
using Android.Graphics;
using Android.OS;
using Android.Runtime;
using Android.Support.V7.App;
using Android.Views;
using Android.Widget;
using System.IO;
using System.Xml;

//====================================================
// Описание работы классов и методов исходника на:
// www.interestprograms.ru
// Исходные коды программ и игр
// Автор исходных кодов Клочков Павел
//====================================================



namespace AppTableLayout
{


    [Activity(Label = "@string/app_name", Theme = "@style/AppTheme", MainLauncher = true)]
    public class MainActivity : AppCompatActivity
    {

        protected override void OnCreate(Bundle savedInstanceState)
        {

            base.OnCreate(savedInstanceState);
            Xamarin.Essentials.Platform.Init(this, savedInstanceState);

            // Set our view from the "main" layout resource
            SetContentView(Resource.Layout.activity_main);


            Init();
        }




        // Необходимые инициализации перед визуализацией приложения.
        private void Init()
        {
            // Получение текстовой информации из базы данных.
            Stream xmlDB = Assets.Open("stories.xml", Android.Content.Res.Access.Streaming);



            // Для облегчения обработки базу данных загружаем в структурированный XML документ.
            XmlDocument xmlDocument = new XmlDocument();
            xmlDocument.Load(xmlDB);
            xmlDB.Close();



            // Получаем все названия рассказов.
            XmlNodeList xmlNodeList = xmlDocument.DocumentElement.SelectNodes("story/name");



            // В дизайнере кнопки этой радиогруппы только для визуального построения макета приложения.
            // Очистим радиогруппу для размещения рабочих RadioButtons.
            RadioGroup radioGroup = this.FindViewById<RadioGroup>(Resource.Id.radioGroupSelect);
            radioGroup.RemoveAllViews();



            // Создаем новые радиокнопки с названиями аналогично 
            // названиям элементов в файле XML.
            // Подключаем событие прикосновения к каждой кнопке.
            foreach (XmlNode item in xmlNodeList)
            {
                RadioButton rb = new RadioButton(this);
                rb.Click += RadioGroupSelect_Click;
                rb.Text = item.InnerText;
                radioGroup.AddView(rb);
            }


            // Подключаем события для RadioButtons 
            // цветовых настроек фона и шрифта книги.
            RadioGroup radioGroupBGColor = this.FindViewById<RadioGroup>(Resource.Id.radioGroupBGColor);
            for (int i = 0; i < radioGroupBGColor.ChildCount; i++)
            {
                RadioButton rb = (RadioButton)radioGroupBGColor.GetChildAt(i);
                rb.Click += RadioButtonsSetting_Click;
            }



            // Подключаем события к группе радиокнопок изменения размера шрифта книги.
            // У всех радиокнопок настроек события обрабатывает один и тот же метод.
            RadioGroup radioGroupScaleFont = this.FindViewById<RadioGroup>(Resource.Id.radioGroupScaleFont);
            for (int i = 0; i < radioGroupScaleFont.ChildCount; i++)
            {
                RadioButton rb = (RadioButton)radioGroupScaleFont.GetChildAt(i);
                rb.Click += RadioButtonsSetting_Click;
            }


            // Подключаем к текстовому полю событие долгого прикосновения.
            // При этом будет скрывается боковой столбец настроек.
            var textView = this.FindViewById<TextView>(Resource.Id.textViewBody);
            textView.LongClick += TextView_LongClick;
        }



        // Метод событий нажатия(прикосновения) радиокнопок настроек. 
        private void RadioButtonsSetting_Click(object sender, System.EventArgs e)
        {
            // Главную таблицу используем для общего фона всех визуальных элементов.
            TableLayout tl = this.FindViewById<TableLayout>(Resource.Id.tableLayoutMain);



            // Настраиваем шрифты заголовка и текстового поля.
            TextView textViewHead = this.FindViewById<TextView>(Resource.Id.textViewHeader);
            TextView textView = this.FindViewById<TextView>(Resource.Id.textViewBody);



            RadioButton rb = (RadioButton)sender;
            switch (rb.Id)
            {
                case Resource.Id.radioButtonDay:

                    // Светлый фон и темный шрифт для дневного чтения книги.
                    tl.SetBackgroundColor(Color.White);
                    textViewHead.SetTextColor(Color.DarkGray);
                    textView.SetTextColor(Color.DarkGray);

                    break;
                case Resource.Id.radioButtonNight:

                    // Темный фон и светлый шрифт для ночного чтения книги.
                    tl.SetBackgroundColor(Color.DarkGray);
                    textViewHead.SetTextColor(Color.LightGray);
                    textView.SetTextColor(Color.LightGray);

                    break;
                case Resource.Id.radioButtonFontNormal:

                    // Стандартный шрифт.
                    textView.TextSize = 14.0f;

                    break;
                case Resource.Id.radioButtonFontLarge:

                    // Увеличенный шрифт.
                    textView.TextSize = 18.0f;

                    break;
            }
        }




        // Метод события долгого прикосновения к текстовому полю.
        private void TextView_LongClick(object sender, View.LongClickEventArgs e)
        {
            // Получаем главную таблицу для управления столбцом настроек.
            TableLayout tl = this.FindViewById<TableLayout>(Resource.Id.tableLayoutMain);



            // Если столбец свернут, возвращаем false для разворачивания,
            // и если столбец развернут возвращаем true для его сворачивания.
            bool collapse = tl.IsColumnCollapsed(1) ? false : true;



            // Выполняем вычисленное действие.
            tl.SetColumnCollapsed(1, collapse);
        }


        // Метод события клика радиокнопок группы выбора рассказа по его названию.
        private void RadioGroupSelect_Click(object sender, System.EventArgs e)
        {

            RadioButton rb = (RadioButton)sender;



            // Заголовок и тело текстового поля.
            TextView textViewHeader = this.FindViewById<TextView>(Resource.Id.textViewHeader);
            TextView textViewBody = this.FindViewById<TextView>(Resource.Id.textViewBody);



            // Получаем ресурс текстовой информации книги.
            Stream xmlDB = Assets.Open("stories.xml", Android.Content.Res.Access.Streaming);



            // Для удобства работы текстовый ресурс загружаем в XML документ.
            XmlDocument xmlDocument = new XmlDocument();
            xmlDocument.Load(xmlDB);
            xmlDB.Close();


            // По тексту нажатой радиокнопки загружаем соответствующий рассказ
            // и название присваиваем заголовку приложения.
            XmlNodeList xmlNodeList = xmlDocument.DocumentElement.SelectNodes("story");
            foreach (XmlNode item in xmlNodeList)
            {
                if (rb.Text == item.SelectSingleNode("name").InnerText)
                {
                    textViewBody.Text = item.SelectSingleNode("body").InnerText;
                    textViewHeader.Text = item.SelectSingleNode("name").InnerText;
                }
            }
        }


        public override void OnRequestPermissionsResult(int requestCode, string[] permissions, [GeneratedEnum] Android.Content.PM.Permission[] grantResults)
        {
            Xamarin.Essentials.Platform.OnRequestPermissionsResult(requestCode, permissions, grantResults);

            base.OnRequestPermissionsResult(requestCode, permissions, grantResults);
        }
    }
}